projectal.entities API documentation

# projectal.entities

Implementations of all Projectal entities.

All classes here inherit from `projectal.entity.Entity`.

View Source

     1"""
     2Implementations of all Projectal entities.
     3
     4All classes here inherit from `projectal.entity.Entity`.
     5"""
     6
     7from projectal.entities.access_policy import AccessPolicy
     8from projectal.entities.activity import Activity
     9from projectal.entities.booking import Booking
    10from projectal.entities.calendar import Calendar
    11from projectal.entities.company import Company
    12from projectal.entities.contact import Contact
    13from projectal.entities.customer import Customer
    14from projectal.entities.department import Department
    15from projectal.entities.file import File
    16from projectal.entities.folder import Folder
    17from projectal.entities.location import Location
    18from projectal.entities.note import Note
    19from projectal.entities.permission import Permission
    20from projectal.entities.project import Project
    21from projectal.entities.project_template import ProjectTemplate
    22from projectal.entities.rebate import Rebate
    23from projectal.entities.resource import Resource
    24from projectal.entities.skill import Skill
    25from projectal.entities.staff import Staff
    26from projectal.entities.stage import Stage
    27from projectal.entities.tag import Tag
    28from projectal.entities.task import Task
    29from projectal.entities.task_template import TaskTemplate
    30from projectal.entities.user import User
    31from projectal.entities.webhook import Webhook